@@ -38,14 +38,14 @@ namespace Plasma
 class RunnerContextPrivate : public QSharedData
 {
 public:
-    RunnerContextPrivate(RunnerContext *context)
+    explicit RunnerContextPrivate(RunnerContext *context)
         : QSharedData()
         , type(RunnerContext::UnknownType)
         , q(context)
     {
     }
 
-    RunnerContextPrivate(const RunnerContextPrivate &p)
+    explicit RunnerContextPrivate(const RunnerContextPrivate &p)
         : QSharedData()
         , launchCounts(p.launchCounts)
         , type(RunnerContext::None)
@@ -337,23 +337,7 @@ bool RunnerContext::addMatches(const QList<QueryMatch> &matches)
 
 bool RunnerContext::addMatch(const QueryMatch &match)
 {
-    if (!isValid()) {
-        // Bail out if the qptr is dirty
-        return false;
-    }
-
-    QueryMatch m(match); // match must be non-const to modify relevance
-
-    LOCK_FOR_WRITE(d)
-
-    if (int count = d->launchCounts.value(m.id())) {
-        m.setRelevance(m.relevance() + 0.05 * count);
-    }
-    d->addMatch(match);
-    UNLOCK(d);
-    Q_EMIT d->q->matchesChanged();
-
-    return true;
+    return addMatches({match});
 }
 
 #if KRUNNER_BUILD_DEPRECATED_SINCE(5, 81)
